Examples
========

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   install.ipynb
   analysis.ipynb

.. toctree::
   :maxdepth: 2
   :caption: Case Studies

   methane
   cl20

.. toctree::
   :maxdepth: 2
   :caption: Publications

   Publications driven by ReacNetGenerator <http://njzjz.win/reacnetgenerator/>
